@@ -9,22 +9,13 @@ import scipy as sp
 from itertools import product
 import phik
 from ipywidgets import interact
+from .tools import dataframe_review
 # pandas options
 pd.set_option('display.max_columns', None)
 pd.set_option('display.width', None)
 pd.set_option('display.max_colwidth', None)
 
 
-# --------------------- #
-# Dataframe type control
-# --------------------- #
-def dataframe_review(data) -> None:
-    if data.__class__.__name__ == 'DataFrame':
-        pass
-    else:
-        raise TypeError('The data loaded is not a DataFrame')
-
-
 # --------------------- #
 # display dataframe side by side
 # --------------------- #
@@ -309,7 +300,7 @@ def plot_categorical(data, col: list[str]) -> None:
 # --------------------- #
 # plot quantitative columns 
 # --------------------- #
-def plot_quantitative(data, col: list[str], bins: int = 50) -> None:
+def plot_numerical(data, col: list[str], bins: int = 50) -> None:
     # dataframe check 
     dataframe_review(data)
     for _, col in enumerate(col):
@@ -391,7 +382,7 @@ def modify_cardinality(data, col: list[str], threshold: list[int]) -> None:
 # correlation pearson (quantitative colum)
 # --------------------- #
 # correlation coefficients for numerical variables (Pearson, Kendall, Spearman)
-def correlation_pearson(data, verbose: bool = True, threshold: float = 0.7) -> None:
+def correlation_pearson(data, threshold: float = 0.) -> None:
     # dataframe check 
     dataframe_review(data)
     # title 
@@ -400,7 +391,7 @@ def correlation_pearson(data, verbose: bool = True, threshold: float = 0.7) -> N
     # correlation matrix 
     corr_mtr = data.corr()
     # graph style 
-    if verbose == True: 
+    if threshold == 0.: 
         corr_mtr = corr_mtr.style.background_gradient()
         display(corr_mtr)
     else: 
@@ -415,7 +406,7 @@ def correlation_pearson(data, verbose: bool = True, threshold: float = 0.7) -> N
 # --------------------- #
 # correlation categorical (chisq test p-values)
 # --------------------- #
-def correlation_categorical(data):
+def correlation_categorical(data) -> None:
     # dataframe check 
     dataframe_review(data)
     # title 
@@ -456,11 +447,11 @@ def correlation_categorical(data):
 # correlation phik (quantitative and categorical columns)
 # --------------------- #
 # https://towardsdatascience.com/phik-k-get-familiar-with-the-latest-correlation-coefficient-9ba0032b37e7
-def correlation_phik(data, theory: bool = False):
+def correlation_phik(data, theory: bool = False) -> None:
     # dataframe check 
     dataframe_review(data)
     # title 
-    string = '### $\phi K$ correlation matrix'
+    string = '### $\phi_K$ correlation matrix'
     display(Markdown(string))
     # interval columns 
     types = data.dtypes
@@ -473,7 +464,7 @@ def correlation_phik(data, theory: bool = False):
     # display
     display(phik_overview)
     if theory == True:
-        string = '* the calculation of $\phi K$ is computationally expensive'
+        string = '* the calculation of $\phi_K$ is computationally expensive'
         string2 = '* no indication of direction'
         string3 = '* no closed-form formula'
         string4 = '* when working with numeric-only variables, other correlation coefficients will be more precise, especially for small samples.'
@@ -490,7 +481,7 @@ def correlation_phik(data, theory: bool = False):
 # --------------------- #
 # Study distribution of a quatitative variable
 # --------------------- #
-def quant_variable_plot(data, col, bins):
+def num_plot(data, col, bins) -> None:
     # figure dim
     plt.figure(figsize = (22, 12))
     # original
@@ -523,7 +514,7 @@ def quant_variable_plot(data, col, bins):
     plt.show()
 
 # useful tests for normality check: shapiro-wilk, wilcoxon, qq-plot
-def quant_variable_study(data, col:str, bins: int = 50, epsilon: float = 0.0001, theory: bool = False) -> None:
+def num_variable_study(data, col:str, bins: int = 50, epsilon: float = 0.0001, theory: bool = False) -> None:
     # dataframe chack step 
     dataframe_review(data)
     # response variable check step 
@@ -533,27 +524,24 @@ def quant_variable_study(data, col:str, bins: int = 50, epsilon: float = 0.0001,
         pass
     # check
     if data[data[col] < 0].shape[0] > 0:
-        print(1)
         string = '## Variable with negative values'
         display(Markdown(string))
         string = "* applied the transformation $x^{'}=x-min(x)+\epsilon$"
         display(Markdown(string))
         x = data[col]
         x = x + abs(min(x))+epsilon
-        quant_variable_plot(data = x, col = col, bins = bins)
+        num_plot(data = x, col = col, bins = bins)
     elif data[data[col] == 0].shape[0] > 0:
-        print(2)
         string = '## Variable with zeros values'
         display(Markdown(string))
         x = data[col]
         x[x==0] = epsilon
-        quant_variable_plot(data = x, col = col, bins = bins)
+        num_plot(data = x, col = col, bins = bins)
     else:
-        print(3)
         string = '## Strickt positive variable'
         display(Markdown(string))
         x = data[col]
-        quant_variable_plot(data = x, col = col, bins = bins)
+        num_plot(data = x, col = col, bins = bins)
     if theory == True:
         # theory behind transformation 
         string = '## Effects of transformations:'
@@ -582,8 +570,8 @@ def quant_variable_study(data, col:str, bins: int = 50, epsilon: float = 0.0001,
         display(Markdown(string),Markdown(string2),Markdown(string3))
         string = '### Reciprocal'
         display(Markdown(string))
-        string = 'It can not be applied to zero values'
-        string2 = 'The reciprocal reverses order among values of the same sign: largestbecomes smallest, etc.'
+        string = '* It can not be applied to zero values'
+        string2 = '* The reciprocal reverses order among values of the same sign: largestbecomes smallest, etc.'
         display(Markdown(string),Markdown(string2))
     else: 
         pass
